.. dpytest documentation master file, created by
   sphinx-quickstart on Thu Apr  9 15:30:30 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the dpytest documentation!
=====================================

The ``dpytest`` library is designed to make testing of discord bots easy and painless.

The library is currently in its infancy, and only supports a subset of the discord API.
Also, the API is not yet finalized, and may change somewhat rapidly. Breaking changes can be
expected until the library hits version 1.0.

.. toctree::
   :maxdepth: 2

   tutorials/index
   modules/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
